#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
import logging
import shutil
import subprocess
import sys

from ingest_envoy.schema import AbstractTextFile


class ImageCollector:
    def __init__(self, parameters):
        self.logger = logging.getLogger("ingest_envoy")
        self.parameters = parameters
        self.spl = parameters["spl"]
        self.staging_source_dir = self.parameters["staging_area"] + "/" + self.parameters["workflowDir"]

    def collect_image_metadata(self) -> AbstractTextFile:
        file = open("./aux_image_metadata.json", "r")
        return AbstractTextFile(file.name, file.read())

    def collect_image_products(self):
        self.logger.info("Collecting image products for staging...")
        workflow_dir = self.parameters["workflowDir"]
        staging_dir = self.parameters["staging_area"]
        tarname = self.create_artifacts_name()

        # run script
        subprocess.run(
            ["./image-product-collector.sh", workflow_dir, staging_dir, tarname],
            stdout=sys.stdout,
            stderr=sys.stderr,
        )
        self.aux_file_to_staging()

    def aux_file_to_staging(self):
        shutil.copy2(
            "./aux_image_metadata.json",
            self.staging_source_dir,
        )

    def create_artifacts_name(self):
        name = "pipeline_artifacts_"
        date = self.parameters["processingStart"]
        return name + date
