# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""multistage restores

Revision ID: 5661f79ddf29
Revises: 09dec567edcd
Create Date: 2021-10-11 15:55:57.500671

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "5661f79ddf29"
down_revision = "09dec567edcd"
branch_labels = None
depends_on = None


dag_content = """JOB FETCH restore_cms_fetch.condor
VARS FETCH jobname="$(JOB)"

JOB ENVOY restore_cms_envoy.condor
VARS ENVOY jobname="$(JOB)"

JOB DELIVER restore_cms_deliver.condor
VARS DELIVER jobname="$(JOB)"

PARENT FETCH CHILD ENVOY
PARENT ENVOY CHILD DELIVER

"""

fetch_content = """executable = restore_cms_fetch.sh
arguments = {{product_locator}} {{cal_locator}}

output = restore_fetch.out
error = restore_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher
transfer_output_files = working, rawdata, products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue

"""

envoy_content = """executable = restore_cms_envoy.sh
arguments = metadata.json PPR.xml

output = restore_envoy.out
error = restore_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, ./working, ./rawdata, ./products{{#remote}}, {{profile}}.properties{{/remote}}, ./PPR.xml, ./metadata.json{{files_to_transfer}}
transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True

{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue

"""

deliver_content = """executable = restore_cms_deliver.sh
arguments = {{request_id}}

output = restore_deliver.out
error = restore_deliver.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/deliver, ./products, ./working

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue

"""

old_content = """executable = restore_cms.sh
arguments = {{product_locator}} {{cal_locator}} {{request_id}} metadata.json PPR.xml

output = restore.out
error = restore.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/deliver, ./PPR.xml, ./metadata.json{{files_to_transfer}}
transfer_output_files = working, rawdata, products, delivery.json

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue

"""


def upgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='restore_cms.condor'
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('restore_cms.dag', E'{dag_content}', 'restore_cms')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('restore_cms_fetch.condor', E'{fetch_content}', 'restore_cms')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('restore_cms_envoy.condor', E'{envoy_content}', 'restore_cms')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('restore_cms_deliver.condor', E'{deliver_content}', 'restore_cms')
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates
        WHERE filename like ('restore_cms_%.condor')
        AND workflow_name = 'restore_cms'
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('restore_cms.condor', E'{old_content}', 'restore_cms')
        """
    )
