# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add actions for qa-pass and qa-fail to complete versions

Revision ID: e0bbf2bf093f
Revises: 9507363ddab7
Create Date: 2021-11-18 12:58:08.894885

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "e0bbf2bf093f"
down_revision = "9507363ddab7"
branch_labels = None
depends_on = None


def upgrade():
    complete_version_sql = """
    INSERT INTO capability_state_actions (transition_id, action_type, arguments)
    SELECT transition_id, 'SendMessage', 'execution_complete'
    FROM capability_state_transitions
    WHERE pattern = 'type == qa-pass'
        AND capability_name = 'std_calibration'
    """
    fail_version_sql = """
    INSERT INTO capability_state_actions (transition_id, action_type, arguments)
    SELECT transition_id, 'SendMessage', 'execution_failed'
    FROM capability_state_transitions
    WHERE pattern = 'type == qa-fail'
        AND capability_name = 'std_calibration'
    """
    op.execute(complete_version_sql)
    op.execute(fail_version_sql)


def downgrade():
    delete_complete_sql = """
    DELETE FROM capability_state_actions
    WHERE action_type = 'SendMessage'
        AND arguments = 'execution_complete'
        AND transition_id = (SELECT transition_id
            FROM capability_state_transitions
            WHERE pattern = 'type == qa-pass'
                AND capability_name = 'std_calibration'
    )
    """
    delete_failed_sql = """
    DELETE FROM capability_state_actions
    WHERE action_type = 'SendMessage'
        AND arguments = 'execution_failed'
        AND transition_id = (SELECT transition_id
            FROM capability_state_transitions
            WHERE pattern = 'type == qa-fail'
                AND capability_name = 'std_calibration'
    )
    """
    op.execute(delete_complete_sql)
    op.execute(delete_failed_sql)
